#!/bin/sh
NGRAPHINSTALLED=/usr/local/lib/Ngraph
XFILESEARCHPATH=\
$NGRAPHINSTALLED/%l/%N:\
$NGRAPHINSTALLED/%N:\
/usr/X11R6/lib/X11/%L/%T/%N%C%S:\
/usr/X11R6/lib/X11/%l/%T/%N%C%S:\
/usr/X11R6/lib/X11/%T/%N%C%S:\
/usr/X11R6/lib/X11/%L/%T/%N%S:\
/usr/X11R6/lib/X11/%l/%T/%N%S:\
/usr/X11R6/lib/X11/%T/%N%S
export XFILESEARCHPATH
${NGRAPHINSTALLED}/ngraph $*
